

%{
#include "wx/pseudodc.h"
%}

%newgroup;

DocStr(wxPseudoDC,
"A PseudoDC is an object that can be used as if it were a DC.  All commands
issued to the PseudoDC are stored in a list.  You can then play these commands
back to a real DC object using the DrawToDC method.  Commands in the command
list are indexed by ID.  You can use this to clear the operations associated 
with a single ID and then re-draw the object associated with that ID.", "");

class wxPseudoDC : public wxObject
{
public:
    DocCtorStr(
        wxPseudoDC(),
        "Constructs a new Pseudo device context for recording dc operations","");
    DocCtorStr(
        ~wxPseudoDC(),
        "Frees memory used by the operation list of the pseudo dc","");
    DocDeclStr(
        void, ClearAll(),
        "Clears all operations from the recorded list.", "");
    DocDeclStr(
        int, GetLen(),
        "Returns the number of operations in the recorded list.", "");
    DocDeclStr(
        void, SetId(int id),
        "Sets the id to be associated with subsequent operations.", "");
    DocDeclStr(
        void, ClearId(int id),
        "Removes all operations form the recorded list associated with id.", "");
    DocDeclStr(
        void, DrawToDCClipped(wxDC *dc, const wxRect& rect),
        "Draws the recorded operations to dc unless the operation is known to
be outside rect.", "");
    DocDeclStr(
        void, DrawToDC(wxDC *dc),
        "Draws the recorded operations to dc.", "");
    DocDeclStr(
        void , SetFont(const wxFont& font),
        "Sets the current font for the DC. It must be a valid font, in
particular you should not pass ``wx.NullFont`` to this method.","

:see: `wx.Font`");
    
    DocDeclStr(
        void , SetPen(const wxPen& pen),
        "Sets the current pen for the DC.

If the argument is ``wx.NullPen``, the current pen is selected out of the
device context, and the original pen restored.", "

:see: `wx.Pen`");
    
    DocDeclStr(
        void , SetBrush(const wxBrush& brush),
        "Sets the current brush for the DC.

If the argument is ``wx.NullBrush``, the current brush is selected out
of the device context, and the original brush restored, allowing the
current brush to be destroyed safely.","

:see: `wx.Brush`");
    
    DocDeclStr(
        void , SetBackground(const wxBrush& brush),
        "Sets the current background brush for the DC.", "");
    
    DocDeclStr(
        void , SetBackgroundMode(int mode),
        "*mode* may be one of ``wx.SOLID`` and ``wx.TRANSPARENT``. This setting
determines whether text will be drawn with a background colour or
not.", "");
    
    DocDeclStr(
        void , SetTextForeground(const wxColour& colour),
        "Sets the current text foreground colour for the DC.", "");
    
    DocDeclStr(
        void , SetTextBackground(const wxColour& colour),
        "Sets the current text background colour for the DC.", "");
    DocDeclStr(
        void , DrawLabel(const wxString& text, const wxRect& rect,
                         int alignment = wxALIGN_LEFT | wxALIGN_TOP,
                         int indexAccel = -1),
        "Draw *text* within the specified rectangle, abiding by the alignment
flags.  Will additionally emphasize the character at *indexAccel* if
it is not -1.", "

:see: `DrawImageLabel`");
    DocStr(
        DrawText,
        "Draws a text string at the specified point, using the current text
font, and the current text foreground and background colours.

The coordinates refer to the top-left corner of the rectangle bounding
the string. See `GetTextExtent` for how to get the dimensions of a
text string, which can be used to position the text more precisely.

**NOTE**: under wxGTK the current logical function is used by this
function but it is ignored by wxMSW. Thus, you should avoid using
logical functions with this function in portable programs.", "

:see: `DrawRotatedText`");
    void DrawText(const wxString& text, wxCoord x, wxCoord y);
    DocStr(
        DrawLine,
        "Draws a line from the first point to the second. The current pen is
used for drawing the line. Note that the second point is *not* part of
the line and is not drawn by this function (this is consistent with
the behaviour of many other toolkits).", "");
    void DrawLine(wxCoord x1, wxCoord y1, wxCoord x2, wxCoord y2);
    DocDeclStr(
        void, DrawRectangle(wxCoord x, wxCoord y, wxCoord width, wxCoord height),
        "Draws a rectangle with the given top left corner, and with the given
size. The current pen is used for the outline and the current brush
for filling the shape.", "");
    DocDeclStr(
        void , Clear(),
        "Clears the device context using the current background brush.", "");
};
